package PNI::Node::Perldata;

our $VERSION = '0.01';

1;
__END__

=head1 NAME

PNI::Node::Perldata - PNI node collection

=head1 DESCRIPTION

It's a basic collection of PNI nodes implementing Perl data types.

=head1 NODES

=over 4

=item L<PNI::Node::Perldata::Scalar>

=back

=head1 SEE ALSO

L<PNI>

=cut
